CVS commit: src/sys/arch/evbarm/awin

2014-09-10 Thread Nick Hudson
Module Name:src
Committed By:   skrll
Date:   Wed Sep 10 07:39:17 UTC 2014

Modified Files:
src/sys/arch/evbarm/awin: awin_machdep.c

Log Message:
Don't grab the ubootinfo structure and try to determine the mac address
from it.  Rely on reading the mac from the chip.


To generate a diff of this commit:
cvs rdiff -u -r1.7 -r1.8 src/sys/arch/evbarm/awin/awin_machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/awin/awin_machdep.c
diff -u src/sys/arch/evbarm/awin/awin_machdep.c:1.7 src/sys/arch/evbarm/awin/awin_machdep.c:1.8
--- src/sys/arch/evbarm/awin/awin_machdep.c:1.7	Wed Sep 10 06:50:13 2014
+++ src/sys/arch/evbarm/awin/awin_machdep.c	Wed Sep 10 07:39:17 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: awin_machdep.c,v 1.7 2014/09/10 06:50:13 matt Exp $ */
+/*	$NetBSD: awin_machdep.c,v 1.8 2014/09/10 07:39:17 skrll Exp $ */
 
 /*
  * Machine dependent functions for kernel setup for TI OSK5912 board.
@@ -125,7 +125,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: awin_machdep.c,v 1.7 2014/09/10 06:50:13 matt Exp $);
+__KERNEL_RCSID(0, $NetBSD: awin_machdep.c,v 1.8 2014/09/10 07:39:17 skrll Exp $);
 
 #include opt_machdep.h
 #include opt_ddb.h
@@ -192,7 +192,6 @@ BootConfig bootconfig;		/* Boot config s
 static char bootargs[MAX_BOOT_STRING];
 char *boot_args = NULL;
 char *boot_file = NULL;
-static uint8_t uboot_enaddr[ETHER_ADDR_LEN];
 
 #if AWIN_board == AWIN_cubieboard
 bool cubietruck_p;
@@ -339,8 +338,6 @@ initarm(void *arg)
 	printf(\nNetBSD/evbarm ( __STRING(BOARDTYPE) ) booting ...\n);
 #endif
 
-	const uint8_t *uboot_bootinfo = (void*)uboot_args[0];
-
 #ifdef BOOT_ARGS
 	char mi_bootargs[] = BOOT_ARGS;
 	parse_mi_bootargs(mi_bootargs);
@@ -419,16 +416,8 @@ initarm(void *arg)
 			 (uboot_args[3] + KERNEL_BASE_VOFFSET);
 			strlcpy(bootargs, args, sizeof(bootargs));
 		}
-		if (uboot_args[0]
-		uboot_args[0] - AWIN_SDRAM_PBASE  ram_size) {
-			uboot_bootinfo =
-			(void*)(uboot_args[0] + KERNEL_BASE_VOFFSET);
-		}
 	}
 
-	/* copy u-boot bootinfo ethernet address */
-	memcpy(uboot_enaddr, uboot_bootinfo + 0x250, sizeof(uboot_enaddr));
-
 	boot_args = bootargs;
 	parse_mi_bootargs(boot_args);
 
@@ -635,12 +624,6 @@ awin_device_register(device_t self, void
 		prop_dictionary_set_uint32(dict, nc-i, 0x003fc03f);
 		return;
 	}
-	if (device_is_a(self, awge) || device_is_a(self, awe)) {
-		prop_data_t blob =
-		prop_data_create_data(uboot_enaddr, ETHER_ADDR_LEN);
-		prop_dictionary_set(dict, mac-address, blob);
-		prop_object_release(blob);
-	}
 
 	if (device_is_a(self, ehci)) {
 		return;



CVS commit: src/sys/dev/wsfb

2014-09-10 Thread Michael Lorenz
Module Name:src
Committed By:   macallan
Date:   Wed Sep 10 07:40:52 UTC 2014

Modified Files:
src/sys/dev/wsfb: genfb.c

Log Message:
handle WSDISPLAYIO_GET_EDID and WSDISPLAYIO_GET_FBINFO only if the bus
frontend doesn't ( as in, returns EPASSTHROUGH or doesn't register a
handler )
Now flags passed from things like bcm2835_genfb.c are actually seen by
xf86-video-wsfb again and automatically disabling shadowfb works again,
which results in a major speedup on this kind of hardware.


To generate a diff of this commit:
cvs rdiff -u -r1.55 -r1.56 src/sys/dev/wsfb/genfb.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/wsfb/genfb.c
diff -u src/sys/dev/wsfb/genfb.c:1.55 src/sys/dev/wsfb/genfb.c:1.56
--- src/sys/dev/wsfb/genfb.c:1.55	Thu Jul 24 21:35:13 2014
+++ src/sys/dev/wsfb/genfb.c	Wed Sep 10 07:40:52 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: genfb.c,v 1.55 2014/07/24 21:35:13 riastradh Exp $ */
+/*	$NetBSD: genfb.c,v 1.56 2014/09/10 07:40:52 macallan Exp $ */
 
 /*-
  * Copyright (c) 2007 Michael Lorenz
@@ -27,7 +27,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: genfb.c,v 1.55 2014/07/24 21:35:13 riastradh Exp $);
+__KERNEL_RCSID(0, $NetBSD: genfb.c,v 1.56 2014/09/10 07:40:52 macallan Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -354,7 +354,7 @@ genfb_ioctl(void *v, void *vs, u_long cm
 	struct wsdisplay_fbinfo *wdf;
 	struct vcons_screen *ms = vd-active;
 	struct wsdisplay_param *param;
-	int new_mode, error, val;
+	int new_mode, error, val, ret;
 
 	switch (cmd) {
 		case WSDISPLAYIO_GINFO:
@@ -459,9 +459,22 @@ genfb_ioctl(void *v, void *vs, u_long cm
 return sc-sc_backlight-gpc_set_parameter(
 sc-sc_backlight-gpc_cookie, val);
 			}
-			return EPASSTHROUGH;
-		
+			return EPASSTHROUGH;		
+	}
+	ret = EPASSTHROUGH;
+	if (sc-sc_ops.genfb_ioctl)
+		ret = sc-sc_ops.genfb_ioctl(sc, vs, cmd, data, flag, l);
+	if (ret != EPASSTHROUGH)
+		return ret;
+	/*
+	 * XXX
+	 * handle these only if there either is no ioctl() handler or it didn't
+	 * know how to deal with them. This allows bus frontends to override
+	 * them but still provides fallback implementations
+	 */
+	switch (cmd) {
 		case WSDISPLAYIO_GET_EDID: {
+			
 			struct wsdisplayio_edid_info *d = data;
 			return wsdisplayio_get_edid(sc-sc_dev, d);
 		}
@@ -470,11 +483,6 @@ genfb_ioctl(void *v, void *vs, u_long cm
 			struct wsdisplayio_fbinfo *fbi = data;
 			return wsdisplayio_get_fbinfo(ms-scr_ri, fbi);
 		}
-		
-		default:
-			if (sc-sc_ops.genfb_ioctl)
-return sc-sc_ops.genfb_ioctl(sc, vs, cmd,
-data, flag, l);
 	}
 	return EPASSTHROUGH;
 }



CVS commit: [netbsd-7] src/sys/fs/puffs

2014-09-10 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Wed Sep 10 08:42:28 UTC 2014

Modified Files:
src/sys/fs/puffs [netbsd-7]: puffs_node.c puffs_vnops.c

Log Message:
Pull up following revision(s) (requested by manu in ticket #79):
sys/fs/puffs/puffs_node.c: revision 1.33
sys/fs/puffs/puffs_vnops.c: revision 1.185
When changing a directory content, update the ctime/mtime in kernel
cache, otherwise the updated ctime/mtime appears after the cached
entry expire.


To generate a diff of this commit:
cvs rdiff -u -r1.31.4.1 -r1.31.4.2 src/sys/fs/puffs/puffs_node.c
cvs rdiff -u -r1.182.2.2 -r1.182.2.3 src/sys/fs/puffs/puffs_vnops.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/fs/puffs/puffs_node.c
diff -u src/sys/fs/puffs/puffs_node.c:1.31.4.1 src/sys/fs/puffs/puffs_node.c:1.31.4.2
--- src/sys/fs/puffs/puffs_node.c:1.31.4.1	Fri Aug 29 11:55:34 2014
+++ src/sys/fs/puffs/puffs_node.c	Wed Sep 10 08:42:28 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: puffs_node.c,v 1.31.4.1 2014/08/29 11:55:34 martin Exp $	*/
+/*	$NetBSD: puffs_node.c,v 1.31.4.2 2014/09/10 08:42:28 martin Exp $	*/
 
 /*
  * Copyright (c) 2005, 2006, 2007  Antti Kantee.  All Rights Reserved.
@@ -30,7 +30,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: puffs_node.c,v 1.31.4.1 2014/08/29 11:55:34 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: puffs_node.c,v 1.31.4.2 2014/09/10 08:42:28 martin Exp $);
 
 #include sys/param.h
 #include sys/hash.h
@@ -180,6 +180,8 @@ puffs_newnode(struct mount *mp, struct v
 		cache_enter(dvp, *vpp, cnp-cn_nameptr, cnp-cn_namelen,
 			cnp-cn_flags);
 
+	puffs_updatenode(VPTOPP(dvp), PUFFS_UPDATECTIME|PUFFS_UPDATEMTIME, 0);
+
 	return 0;
 }
 

Index: src/sys/fs/puffs/puffs_vnops.c
diff -u src/sys/fs/puffs/puffs_vnops.c:1.182.2.2 src/sys/fs/puffs/puffs_vnops.c:1.182.2.3
--- src/sys/fs/puffs/puffs_vnops.c:1.182.2.2	Fri Aug 29 11:55:34 2014
+++ src/sys/fs/puffs/puffs_vnops.c	Wed Sep 10 08:42:28 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: puffs_vnops.c,v 1.182.2.2 2014/08/29 11:55:34 martin Exp $	*/
+/*	$NetBSD: puffs_vnops.c,v 1.182.2.3 2014/09/10 08:42:28 martin Exp $	*/
 
 /*
  * Copyright (c) 2005, 2006, 2007  Antti Kantee.  All Rights Reserved.
@@ -30,7 +30,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: puffs_vnops.c,v 1.182.2.2 2014/08/29 11:55:34 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: puffs_vnops.c,v 1.182.2.3 2014/09/10 08:42:28 martin Exp $);
 
 #include sys/param.h
 #include sys/buf.h
@@ -1805,6 +1805,8 @@ puffs_vnop_remove(void *v)
 
 	PUFFS_MSG_RELEASE(remove);
 
+	puffs_updatenode(VPTOPP(dvp), PUFFS_UPDATECTIME|PUFFS_UPDATEMTIME, 0);
+
 	RELEPN_AND_VP(dvp, dpn);
 	RELEPN_AND_VP(vp, pn);
 
@@ -1922,6 +1924,8 @@ puffs_vnop_rmdir(void *v)
 
 	PUFFS_MSG_RELEASE(rmdir);
 
+	puffs_updatenode(VPTOPP(dvp), PUFFS_UPDATECTIME|PUFFS_UPDATEMTIME, 0);
+
 	/* XXX: some call cache_purge() *for both vnodes* here, investigate */
 	RELEPN_AND_VP(dvp, dpn);
 	RELEPN_AND_VP(vp, pn);
@@ -1967,8 +1971,11 @@ puffs_vnop_link(void *v)
 	 * XXX: stay in touch with the cache.  I don't like this, but
 	 * don't have a better solution either.  See also puffs_rename().
 	 */
-	if (error == 0)
+	if (error == 0) {
 		puffs_updatenode(pn, PUFFS_UPDATECTIME, 0);
+		puffs_updatenode(VPTOPP(dvp),
+ PUFFS_UPDATECTIME|PUFFS_UPDATEMTIME, 0);
+	}
 
 	RELEPN_AND_VP(dvp, dpn);
 	puffs_releasenode(pn);
@@ -2133,6 +2140,12 @@ puffs_vnop_rename(void *v)
 	 */
 	if (error == 0) {
 		puffs_updatenode(fpn, PUFFS_UPDATECTIME, 0);
+		puffs_updatenode(VPTOPP(fdvp),
+ PUFFS_UPDATECTIME|PUFFS_UPDATEMTIME, 0);
+		if (fdvp != tdvp)
+			puffs_updatenode(VPTOPP(tdvp),
+	 PUFFS_UPDATECTIME|PUFFS_UPDATEMTIME,
+	 0);
 
 		if (PUFFS_USE_DOTDOTCACHE(pmp) 
 		(VPTOPP(fvp)-pn_parent != tdvp))



CVS commit: [netbsd-7] src/usr.sbin/pcictl

2014-09-10 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Wed Sep 10 08:38:31 UTC 2014

Modified Files:
src/usr.sbin/pcictl [netbsd-7]: pcictl.8 pcictl.c

Log Message:
Pull up following revision(s) (requested by manu in ticket #77):
usr.sbin/pcictl/pcictl.c: revision 1.21
usr.sbin/pcictl/pcictl.8: revision 1.14
Read and write commands for pcictl, from riastradh@ and wiz@,
as discussed on tech-kern.


To generate a diff of this commit:
cvs rdiff -u -r1.10 -r1.10.22.1 src/usr.sbin/pcictl/pcictl.8
cvs rdiff -u -r1.18 -r1.18.20.1 src/usr.sbin/pcictl/pcictl.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.sbin/pcictl/pcictl.8
diff -u src/usr.sbin/pcictl/pcictl.8:1.10 src/usr.sbin/pcictl/pcictl.8:1.10.22.1
--- src/usr.sbin/pcictl/pcictl.8:1.10	Fri Feb 25 21:40:48 2011
+++ src/usr.sbin/pcictl/pcictl.8	Wed Sep 10 08:38:31 2014
@@ -1,4 +1,4 @@
-.\	$NetBSD: pcictl.8,v 1.10 2011/02/25 21:40:48 jmcneill Exp $
+.\	$NetBSD: pcictl.8,v 1.10.22.1 2014/09/10 08:38:31 martin Exp $
 .\
 .\ Copyright 2001 Wasabi Systems, Inc.
 .\ All rights reserved.
@@ -79,6 +79,31 @@ at the specified bus, device, and functi
 If the bus is not specified, it defaults to the bus number of the
 PCI bus specified on the command line.
 If the function is not specified, it defaults to 0.
+.Pp
+.Nm read
+.Op Fl b Ar bus
+.Fl d Ar device
+.Op Fl f Ar function
+.Ar reg
+.Pp
+Read the specified 32-bit aligned PCI configuration register and print
+it in hexadecimal to standard output.
+If the bus is not specified, it defaults to the bus number of the
+PCI bus specified on the command line.
+If the function is not specified, it defaults to 0.
+.Pp
+.Nm write
+.Op Fl b Ar bus
+.Fl d Ar device
+.Op Fl f Ar function
+.Ar reg
+.Ar value
+.Pp
+Write the specified value to the specified 32-bit aligned PCI
+configuration register.
+If the bus is not specified, it defaults to the bus number of the
+PCI bus specified on the command line.
+If the function is not specified, it defaults to 0.
 .Sh FILES
 .Pa /dev/pci*
 - PCI bus device nodes

Index: src/usr.sbin/pcictl/pcictl.c
diff -u src/usr.sbin/pcictl/pcictl.c:1.18 src/usr.sbin/pcictl/pcictl.c:1.18.20.1
--- src/usr.sbin/pcictl/pcictl.c:1.18	Tue Aug 30 20:08:38 2011
+++ src/usr.sbin/pcictl/pcictl.c	Wed Sep 10 08:38:31 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: pcictl.c,v 1.18 2011/08/30 20:08:38 joerg Exp $	*/
+/*	$NetBSD: pcictl.c,v 1.18.20.1 2014/09/10 08:38:31 martin Exp $	*/
 
 /*
  * Copyright 2001 Wasabi Systems, Inc.
@@ -76,6 +76,8 @@ static int	print_numbers = 0;
 
 static void	cmd_list(int, char *[]);
 static void	cmd_dump(int, char *[]);
+static void	cmd_read(int, char *[]);
+static void	cmd_write(int, char *[]);
 
 static const struct command commands[] = {
 	{ list,
@@ -88,10 +90,21 @@ static const struct command commands[] =
 	  cmd_dump,
 	  O_RDONLY },
 
+	{ read,
+	  [-b bus] -d device [-f function] reg,
+	  cmd_read,
+	  O_RDONLY },
+
+	{ write,
+	  [-b bus] -d device [-f function] reg value,
+	  cmd_write,
+	  O_WRONLY },
+
 	{ 0, 0, 0, 0 },
 };
 
 static int	parse_bdf(const char *);
+static u_int	parse_reg(const char *);
 
 static void	scan_pci(int, int, int, void (*)(u_int, u_int, u_int));
 
@@ -230,6 +243,87 @@ cmd_dump(int argc, char *argv[])
 	scan_pci(bus, dev, func, scan_pci_dump);
 }
 
+static void
+cmd_read(int argc, char *argv[])
+{
+	int bus, dev, func;
+	u_int reg;
+	pcireg_t value;
+	int ch;
+
+	bus = pci_businfo.busno;
+	func = 0;
+	dev = -1;
+
+	while ((ch = getopt(argc, argv, b:d:f:)) != -1) {
+		switch (ch) {
+		case 'b':
+			bus = parse_bdf(optarg);
+			break;
+		case 'd':
+			dev = parse_bdf(optarg);
+			break;
+		case 'f':
+			func = parse_bdf(optarg);
+			break;
+		default:
+			usage();
+		}
+	}
+	argv += optind;
+	argc -= optind;
+
+	if (argc != 1)
+		usage();
+	reg = parse_reg(argv[0]);
+	if (pcibus_conf_read(pcifd, bus, dev, func, reg, value) == -1)
+		err(EXIT_FAILURE, pcibus_conf_read
+		(bus %d dev %d func %d reg %u), bus, dev, func, reg);
+	if (printf(%08x\n, value)  0)
+		err(EXIT_FAILURE, printf);
+}
+
+static void
+cmd_write(int argc, char *argv[])
+{
+	int bus, dev, func;
+	u_int reg;
+	pcireg_t value;
+	int ch;
+
+	bus = pci_businfo.busno;
+	func = 0;
+	dev = -1;
+
+	while ((ch = getopt(argc, argv, b:d:f:)) != -1) {
+		switch (ch) {
+		case 'b':
+			bus = parse_bdf(optarg);
+			break;
+		case 'd':
+			dev = parse_bdf(optarg);
+			break;
+		case 'f':
+			func = parse_bdf(optarg);
+			break;
+		default:
+			usage();
+		}
+	}
+	argv += optind;
+	argc -= optind;
+
+	if (argc != 2)
+		usage();
+	reg = parse_reg(argv[0]);
+	__CTASSERT(sizeof(value) == sizeof(u_int));
+	value = parse_reg(argv[1]);
+	if (pcibus_conf_write(pcifd, bus, dev, func, reg, value) == -1)
+		err(EXIT_FAILURE, pcibus_conf_write
+		(bus %d dev %d func %d reg %u value 0x%x),
+		bus, dev, func, reg, value);
+}
+
 static int
 parse_bdf(const char *str)
 {
@@ -240,9 +334,32 @@ 

CVS commit: [netbsd-7] src/sys/arch/evbarm

2014-09-10 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Wed Sep 10 09:37:51 UTC 2014

Modified Files:
src/sys/arch/evbarm/conf [netbsd-7]: CUBIEBOARD CUBIETRUCK
Added Files:
src/sys/arch/evbarm/awin [netbsd-7]: awin_machdep.c awin_start.S
genassym.cf platform.h
src/sys/arch/evbarm/conf [netbsd-7]: BPI files.awin mk.awin std.awin
Removed Files:
src/sys/arch/evbarm/conf [netbsd-7]: files.cubie mk.cubie std.cubie
src/sys/arch/evbarm/cubie [netbsd-7]: cubie_machdep.c cubie_start.S
genassym.cf platform.h

Log Message:
Pull up following revision(s) (requested by skrll in ticket #82):
sys/arch/evbarm/awin/awin_start.S: revision 1.1
sys/arch/evbarm/conf/mk.cubie: file removal
sys/arch/evbarm/conf/std.awin: revision 1.1
sys/arch/evbarm/cubie/genassym.cf: file removal
sys/arch/evbarm/conf/CUBIEBOARD: revision 1.17
sys/arch/evbarm/conf/BPI: revision 1.1
sys/arch/evbarm/awin/genassym.cf: revision 1.1
sys/arch/evbarm/awin/platform.h: revision 1.1
sys/arch/evbarm/conf/files.awin: revision 1.1
sys/arch/evbarm/conf/mk.cubie: revision 1.4
sys/arch/evbarm/conf/CUBIETRUCK: revision 1.3
sys/arch/evbarm/cubie/cubie_machdep.c: revision 1.21
sys/arch/evbarm/awin/awin_machdep.c: revision 1.1
sys/arch/evbarm/awin/awin_machdep.c: revision 1.3
sys/arch/evbarm/awin/awin_machdep.c: revision 1.4
sys/arch/evbarm/conf/std.cubie: file removal
sys/arch/evbarm/conf/mk.awin: revision 1.1
sys/arch/evbarm/conf/mk.awin: revision 1.2
sys/arch/evbarm/cubie/cubie_machdep.c: file removal
sys/arch/evbarm/cubie/cubie_start.S: file removal
sys/arch/evbarm/cubie/platform.h: file removal
sys/arch/evbarm/conf/files.cubie: file removal

Move away from cubie to generic awin and introduce a BOARDTYPE
variable. This allows other boards to use the cubie code.

Add a Banana Pi kernel config and fixup mmc0detect assignment for BPI.


To generate a diff of this commit:
cvs rdiff -u -r0 -r1.8.2.2 src/sys/arch/evbarm/awin/awin_machdep.c
cvs rdiff -u -r0 -r1.1.2.2 src/sys/arch/evbarm/awin/awin_start.S \
src/sys/arch/evbarm/awin/genassym.cf src/sys/arch/evbarm/awin/platform.h
cvs rdiff -u -r0 -r1.2.2.2 src/sys/arch/evbarm/conf/BPI \
src/sys/arch/evbarm/conf/mk.awin
cvs rdiff -u -r1.12 -r1.12.2.1 src/sys/arch/evbarm/conf/CUBIEBOARD
cvs rdiff -u -r1.2 -r1.2.4.1 src/sys/arch/evbarm/conf/CUBIETRUCK
cvs rdiff -u -r0 -r1.1.2.2 src/sys/arch/evbarm/conf/files.awin \
src/sys/arch/evbarm/conf/std.awin
cvs rdiff -u -r1.1 -r0 src/sys/arch/evbarm/conf/files.cubie
cvs rdiff -u -r1.3 -r0 src/sys/arch/evbarm/conf/mk.cubie \
src/sys/arch/evbarm/conf/std.cubie
cvs rdiff -u -r1.19 -r0 src/sys/arch/evbarm/cubie/cubie_machdep.c
cvs rdiff -u -r1.9 -r0 src/sys/arch/evbarm/cubie/cubie_start.S
cvs rdiff -u -r1.1 -r0 src/sys/arch/evbarm/cubie/genassym.cf
cvs rdiff -u -r1.2 -r0 src/sys/arch/evbarm/cubie/platform.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/conf/CUBIEBOARD
diff -u src/sys/arch/evbarm/conf/CUBIEBOARD:1.12 src/sys/arch/evbarm/conf/CUBIEBOARD:1.12.2.1
--- src/sys/arch/evbarm/conf/CUBIEBOARD:1.12	Sun Aug  3 08:53:56 2014
+++ src/sys/arch/evbarm/conf/CUBIEBOARD	Wed Sep 10 09:37:51 2014
@@ -1,10 +1,10 @@
 #
-#	$NetBSD: CUBIEBOARD,v 1.12 2014/08/03 08:53:56 martin Exp $
+#	$NetBSD: CUBIEBOARD,v 1.12.2.1 2014/09/10 09:37:51 martin Exp $
 #
 #	CUBIEBOARD -- Allwinner A10/A20 Eval Board Kernel
 #
 
-include	arch/evbarm/conf/std.cubie
+include	arch/evbarm/conf/std.awin
 
 # estimated number of users
 
@@ -17,6 +17,8 @@ options 	RTC_OFFSET=0	# hardware clock i
 
 # CPU options
 
+no makeoptions	BOARDTYPE
+makeoptions	BOARDTYPE=cubieboard
 #options 	UVMHIST,UVMHIST_PRINT
 options 	CPU_CORTEXA8
 options 	CPU_CORTEXA7
@@ -164,7 +166,7 @@ config		netbsd		root on ? type ?
 mainbus0	at root
 
 # The boot cpu
-cpu0		at mainbus?
+cpu*		at mainbus?
 
 # Specify the memory size in megabytes (optional).
 #options 	MEMSIZE=256

Index: src/sys/arch/evbarm/conf/CUBIETRUCK
diff -u src/sys/arch/evbarm/conf/CUBIETRUCK:1.2 src/sys/arch/evbarm/conf/CUBIETRUCK:1.2.4.1
--- src/sys/arch/evbarm/conf/CUBIETRUCK:1.2	Sun Aug  3 08:53:56 2014
+++ src/sys/arch/evbarm/conf/CUBIETRUCK	Wed Sep 10 09:37:51 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: CUBIETRUCK,v 1.2 2014/08/03 08:53:56 martin Exp $
+#	$NetBSD: CUBIETRUCK,v 1.2.4.1 2014/09/10 09:37:51 martin Exp $
 #
 #	CUBIETRUCK - Cubieboard3 (mostly cubieboard2 with 2GB)
 #
@@ -10,8 +10,10 @@ include arch/evbarm/conf/CUBIEBOARD
 #
 no makeoptions	KERNEL_BASE_PHYS
 no makeoptions	KERNEL_BASE_VIRT
+no makeoptions	BOARDTYPE
 makeoptions	KERNEL_BASE_PHYS=0x8000
 makeoptions	KERNEL_BASE_VIRT=0x8000
+makeoptions	BOARDTYPE=cubietruck
 
 #
 # We need this too.

Added files:

Index: 

CVS commit: src/sys/arch/evbarm/conf

2014-09-10 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Wed Sep 10 09:55:09 UTC 2014

Modified Files:
src/sys/arch/evbarm/conf: std.awin

Log Message:
options GTTWSI_ALLWINNER


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/sys/arch/evbarm/conf/std.awin

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/conf/std.awin
diff -u src/sys/arch/evbarm/conf/std.awin:1.1 src/sys/arch/evbarm/conf/std.awin:1.2
--- src/sys/arch/evbarm/conf/std.awin:1.1	Sun Aug 31 19:13:01 2014
+++ src/sys/arch/evbarm/conf/std.awin	Wed Sep 10 09:55:09 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: std.awin,v 1.1 2014/08/31 19:13:01 matt Exp $
+#	$NetBSD: std.awin,v 1.2 2014/09/10 09:55:09 matt Exp $
 #
 # standard NetBSD/evbarm for Allwinner based options
 
@@ -19,6 +19,7 @@ options 	__HAVE_MM_MD_DIRECT_MAPPED_PHYS
 options 	TPIDRPRW_IS_CURCPU
 options 	KERNEL_BASE_EXT=0x8000
 options 	FPU_VFP
+options 	GTTWSI_ALLWINNER
 
 makeoptions	KERNEL_BASE_PHYS=0x40007800
 makeoptions	KERNEL_BASE_VIRT=0x80007800



CVS commit: [netbsd-7] src/sys/arch/evbarm/awin

2014-09-10 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Wed Sep 10 10:10:43 UTC 2014

Modified Files:
src/sys/arch/evbarm/awin [netbsd-7]: awin_machdep.c

Log Message:
Fix merge botch in ticket #82


To generate a diff of this commit:
cvs rdiff -u -r1.8.2.2 -r1.8.2.3 src/sys/arch/evbarm/awin/awin_machdep.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/evbarm/awin/awin_machdep.c
diff -u src/sys/arch/evbarm/awin/awin_machdep.c:1.8.2.2 src/sys/arch/evbarm/awin/awin_machdep.c:1.8.2.3
--- src/sys/arch/evbarm/awin/awin_machdep.c:1.8.2.2	Wed Sep 10 09:37:51 2014
+++ src/sys/arch/evbarm/awin/awin_machdep.c	Wed Sep 10 10:10:43 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: awin_machdep.c,v 1.8.2.2 2014/09/10 09:37:51 martin Exp $ */
+/*	$NetBSD: awin_machdep.c,v 1.8.2.3 2014/09/10 10:10:43 martin Exp $ */
 
 /*
  * Machine dependent functions for kernel setup for TI OSK5912 board.
@@ -125,7 +125,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: awin_machdep.c,v 1.8.2.2 2014/09/10 09:37:51 martin Exp $);
+__KERNEL_RCSID(0, $NetBSD: awin_machdep.c,v 1.8.2.3 2014/09/10 10:10:43 martin Exp $);
 
 #include opt_machdep.h
 #include opt_ddb.h
@@ -619,7 +619,11 @@ awin_device_register(device_t self, void
 			prop_dictionary_set_cstring(dict, hdd5ven, PH17);
 			prop_dictionary_set_cstring(dict, emacpwren, PH19);
 		}
+#if AWIN_board == AWIN_cubieboard || AWIN_board == AWIN_cubietruck
 		prop_dictionary_set_cstring(dict, mmc0detect, PH1);
+#elif AWIN_board == AWIN_bpi
+		prop_dictionary_set_cstring(dict, mmc0detect, PH10);
+#endif
 
 		/*
 		 * These pins have no connections.



CVS commit: src/sbin/gpt

2014-09-10 Thread John Nemeth
Module Name:src
Committed By:   jnemeth
Date:   Wed Sep 10 10:49:44 UTC 2014

Modified Files:
src/sbin/gpt: backup.c

Log Message:
- dump all partitions, not just ones that are in use
- while here, squash a memory leak

 It shouldn't be necessary to backup unused partitions, however
the partition GUID is created at the time the GPT is created and
is never changed.  It shouldn't matter if the GUID of an unused
partition changes, but there may be some special case where it
does.  Since it isn't a big deal to record the unused partitions,
might as well do it.


To generate a diff of this commit:
cvs rdiff -u -r1.2 -r1.3 src/sbin/gpt/backup.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sbin/gpt/backup.c
diff -u src/sbin/gpt/backup.c:1.2 src/sbin/gpt/backup.c:1.3
--- src/sbin/gpt/backup.c:1.2	Tue Sep  9 06:30:09 2014
+++ src/sbin/gpt/backup.c	Wed Sep 10 10:49:44 2014
@@ -29,7 +29,7 @@
 __FBSDID($FreeBSD: src/sbin/gpt/show.c,v 1.14 2006/06/22 22:22:32 marcel Exp $);
 #endif
 #ifdef __RCSID
-__RCSID($NetBSD: backup.c,v 1.2 2014/09/09 06:30:09 jnemeth Exp $);
+__RCSID($NetBSD: backup.c,v 1.3 2014/09/10 10:49:44 jnemeth Exp $);
 #endif
 
 #include sys/bootblock.h
@@ -216,12 +216,11 @@ backup(void)
 			type_dict = prop_dictionary_create();
 			PROP_ERR(type_dict);
 			ent = m-map_data;
-			gpt_array = NULL;
+			gpt_array = prop_array_create();
+			PROP_ERR(gpt_array);
 			for (i = 1, ent = m-map_data;
 			(char *)ent  (char *)(m-map_data) +
 			m-map_size * secsz; i++, ent++) {
-if (uuid_is_nil((uuid_t *)ent-ent_type, NULL))
-	continue;
 gpt_dict = prop_dictionary_create();
 PROP_ERR(gpt_dict);
 propnum = prop_number_create_integer(i);
@@ -267,19 +266,13 @@ backup(void)
 	name, propstr);
 	PROP_ERR(rc);
 }
-if (gpt_array == NULL) {
-	gpt_array = prop_array_create();
-	PROP_ERR(gpt_array);
-}
 rc = prop_array_add(gpt_array, gpt_dict);
 PROP_ERR(rc);
 			}
-			if (gpt_array != NULL) {
-rc = prop_dictionary_set(type_dict,
-gpt_array, gpt_array);
-PROP_ERR(rc);
-prop_object_release(gpt_array);
-			}
+			rc = prop_dictionary_set(type_dict,
+			gpt_array, gpt_array);
+			PROP_ERR(rc);
+			prop_object_release(gpt_array);
 			rc = prop_dictionary_set(props, GPT_TBL, type_dict);
 			PROP_ERR(rc);
 			prop_object_release(type_dict);
@@ -291,6 +284,7 @@ backup(void)
 	PROP_ERR(propext);
 	prop_object_release(props);
 	fputs(propext, stdout);
+	free(propext);
 }
 
 int



CVS commit: src/sys/arch/arm/broadcom

2014-09-10 Thread Jonathan A. Kollasch
Module Name:src
Committed By:   jakllsch
Date:   Wed Sep 10 13:45:52 UTC 2014

Modified Files:
src/sys/arch/arm/broadcom: bcm2835_emmc.c

Log Message:
Drop unused local-softc variable.


To generate a diff of this commit:
cvs rdiff -u -r1.9 -r1.10 src/sys/arch/arm/broadcom/bcm2835_emmc.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/broadcom/bcm2835_emmc.c
diff -u src/sys/arch/arm/broadcom/bcm2835_emmc.c:1.9 src/sys/arch/arm/broadcom/bcm2835_emmc.c:1.10
--- src/sys/arch/arm/broadcom/bcm2835_emmc.c:1.9	Thu Sep  5 07:06:37 2013
+++ src/sys/arch/arm/broadcom/bcm2835_emmc.c	Wed Sep 10 13:45:52 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: bcm2835_emmc.c,v 1.9 2013/09/05 07:06:37 skrll Exp $	*/
+/*	$NetBSD: bcm2835_emmc.c,v 1.10 2014/09/10 13:45:52 jakllsch Exp $	*/
 
 /*-
  * Copyright (c) 2012 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: bcm2835_emmc.c,v 1.9 2013/09/05 07:06:37 skrll Exp $);
+__KERNEL_RCSID(0, $NetBSD: bcm2835_emmc.c,v 1.10 2014/09/10 13:45:52 jakllsch Exp $);
 
 #include sys/param.h
 #include sys/systm.h
@@ -46,7 +46,6 @@ __KERNEL_RCSID(0, $NetBSD: bcm2835_emmc
 
 struct bcmemmc_softc {
 	struct sdhc_softc	sc;
-	device_t		sc_sdmmc;
 
 	bus_space_tag_t		sc_iot;
 	bus_space_handle_t	sc_ioh;



CVS commit: src/share/man/man9

2014-09-10 Thread Martin Husemann
Module Name:src
Committed By:   martin
Date:   Wed Sep 10 14:28:02 UTC 2014

Modified Files:
src/share/man/man9: todr.9

Log Message:
Adapt to recent changes.


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 src/share/man/man9/todr.9

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/share/man/man9/todr.9
diff -u src/share/man/man9/todr.9:1.17 src/share/man/man9/todr.9:1.18
--- src/share/man/man9/todr.9:1.17	Sat Aug 30 14:48:10 2014
+++ src/share/man/man9/todr.9	Wed Sep 10 14:28:02 2014
@@ -1,4 +1,4 @@
-.\ $NetBSD: todr.9,v 1.17 2014/08/30 14:48:10 martin Exp $
+.\ $NetBSD: todr.9,v 1.18 2014/09/10 14:28:02 martin Exp $
 .\
 .\ Copyright (c) 2000, 2003 The NetBSD Foundation, Inc.
 .\ All rights reserved.
@@ -27,7 +27,7 @@
 .\ ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 .\ POSSIBILITY OF SUCH DAMAGE.
 .\
-.Dd September 6, 2006
+.Dd September 10, 2014
 .Dt TODR 9
 .Os
 .Sh NAME
@@ -45,7 +45,7 @@
 .Fn todr_gettime todr_chip_handle_t struct timeval *
 .Ft int
 .Fn todr_settime todr_chip_handle_t struct timeval *
-.Ft void
+.Ft int
 .Fn clock_secs_to_ymdhms time_t struct clock_ymdhms *
 .Ft time_t
 .Fn clock_ymdhms_to_secs struct clock_ymdhms *
@@ -92,7 +92,7 @@ tuple.
 This structure is defined as follows:
 .Bd -literal
 struct clock_ymdhms {
-	u_short dt_year;	/* Year */
+	uint64_t dt_year;	/* Year */
 	u_char dt_mon;		/* Month (1-12) */
 	u_char dt_day;		/* Day (1-31) */
 	u_char dt_wday;		/* Day of week (0-6) */
@@ -121,7 +121,9 @@ large to fit in a
 .Fa time_t .
 The
 .Fn clock_secs_to_ymdhms
-function never fails.
+function returns 0 on success or
+.Er EINVAL
+if the time passed is negative.
 .Sh SEE ALSO
 .Xr intersil7170 4 ,
 .Xr mk48txx 4 ,



CVS commit: src/sys/external/bsd/drm2/ttm

2014-09-10 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Wed Sep 10 18:24:16 UTC 2014

Modified Files:
src/sys/external/bsd/drm2/ttm: ttm_bo_vm.c

Log Message:
We dropped vmobjlock, so reacquire it before uvmfault_unlockall.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/sys/external/bsd/drm2/ttm/ttm_bo_vm.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/crypto/dist/ipsec-tools/src/setkey/token.l
diff -u src/crypto/dist/ipsec-tools/src/setkey/token.l:1.18 src/crypto/dist/ipsec-tools/src/setkey/token.l:1.19
--- src/crypto/dist/ipsec-tools/src/setkey/token.l:1.18	Thu Nov 29 10:31:25 2012
+++ src/crypto/dist/ipsec-tools/src/setkey/token.l	Wed Sep 10 17:01:33 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: token.l,v 1.18 2012/11/29 15:31:25 vanhu Exp $	*/
+/*	$NetBSD: token.l,v 1.19 2014/09/10 21:01:33 christos Exp $	*/
 
 /*	$KAME: token.l,v 1.44 2003/10/21 07:20:58 itojun Exp $	*/
 
@@ -233,16 +233,6 @@ tcp		{ 
 	yylval.num = SADB_X_EALG_AESGMAC; BEGIN INITIAL; return(ALG_ENC);
 #endif
 }
-S_ENCALGaes-gcm-16   {
-#ifdef SADB_X_EALG_AESGCM16
-	yylval.num = SADB_X_EALG_AESGCM16; BEGIN INITIAL; return(ALG_ENC);
-#endif
-}
-S_ENCALGaes-gmac {
-#ifdef SADB_X_EALG_AESGMAC
-	yylval.num = SADB_X_EALG_AESGMAC; BEGIN INITIAL; return(ALG_ENC);
-#endif
-}
 
 	/* compression algorithms */
 {hyphen}C	{ return(F_COMP); }



CVS commit: src/crypto/dist/ipsec-tools/src/setkey

2014-09-10 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Wed Sep 10 21:04:08 UTC 2014

Modified Files:
src/crypto/dist/ipsec-tools/src/setkey: parse.y

Log Message:
fix grammar stupidity: ipandport takes an optional port but has 2 grammar
productions, one with and one without an optional port. make the port
not optional and kill reduce-reduce conflicts.


To generate a diff of this commit:
cvs rdiff -u -r1.16 -r1.17 src/crypto/dist/ipsec-tools/src/setkey/parse.y

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/crypto/dist/ipsec-tools/src/setkey/parse.y
diff -u src/crypto/dist/ipsec-tools/src/setkey/parse.y:1.16 src/crypto/dist/ipsec-tools/src/setkey/parse.y:1.17
--- src/crypto/dist/ipsec-tools/src/setkey/parse.y:1.16	Sun Oct 20 17:17:28 2013
+++ src/crypto/dist/ipsec-tools/src/setkey/parse.y	Wed Sep 10 17:04:08 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: parse.y,v 1.16 2013/10/20 21:17:28 christos Exp $	*/
+/*	$NetBSD: parse.y,v 1.17 2014/09/10 21:04:08 christos Exp $	*/
 
 /*	$KAME: parse.y,v 1.81 2003/07/01 04:01:48 itojun Exp $	*/
 
@@ -141,7 +141,7 @@ static int setkeymsg_add __P((unsigned i
 %type num PR_ESP PR_AH PR_IPCOMP PR_ESPUDP PR_TCP
 %type num EXTENSION MODE
 %type ulnum DECSTRING
-%type val PL_REQUESTS portstr key_string
+%type val PL_REQUESTS portstr portstr_notempty key_string
 %type val policy_requests
 %type val QUOTEDSTRING HEXSTRING STRING
 %type val F_AIFLAGS
@@ -772,7 +772,7 @@ ipandport
 return -1;
 			}
 		}
-	|	STRING portstr
+	|	STRING portstr_notempty
 		{
 			$$ = parse_addr($1.buf, $2.buf);
 			if ($$ == NULL) {
@@ -797,7 +797,11 @@ portstr
 			}
 			$$.len = strlen($$.buf);
 		}
-	|	BLCL ANY ELCL
+	| portstr_notempty
+	;
+
+portstr_notempty
+	: 	BLCL ANY ELCL
 		{
 			$$.buf = strdup(0);
 			if (!$$.buf) {



CVS commit: src/usr.sbin/pcictl

2014-09-10 Thread Taylor R Campbell
Module Name:src
Committed By:   riastradh
Date:   Wed Sep 10 21:09:32 UTC 2014

Modified Files:
src/usr.sbin/pcictl: pcictl.8

Log Message:
Sternly advise against `pcictl read/write'.  Use .Cm, not .Nm, while here.


To generate a diff of this commit:
cvs rdiff -u -r1.14 -r1.15 src/usr.sbin/pcictl/pcictl.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.sbin/pcictl/pcictl.8
diff -u src/usr.sbin/pcictl/pcictl.8:1.14 src/usr.sbin/pcictl/pcictl.8:1.15
--- src/usr.sbin/pcictl/pcictl.8:1.14	Mon Sep  1 07:11:19 2014
+++ src/usr.sbin/pcictl/pcictl.8	Wed Sep 10 21:09:32 2014
@@ -1,4 +1,4 @@
-.\	$NetBSD: pcictl.8,v 1.14 2014/09/01 07:11:19 manu Exp $
+.\	$NetBSD: pcictl.8,v 1.15 2014/09/10 21:09:32 riastradh Exp $
 .\
 .\ Copyright 2001 Wasabi Systems, Inc.
 .\ All rights reserved.
@@ -84,7 +84,7 @@ If the bus is not specified, it defaults
 PCI bus specified on the command line.
 If the function is not specified, it defaults to 0.
 .Pp
-.Nm read
+.Cm read
 .Op Fl b Ar bus
 .Fl d Ar device
 .Op Fl f Ar function
@@ -96,7 +96,16 @@ If the bus is not specified, it defaults
 PCI bus specified on the command line.
 If the function is not specified, it defaults to 0.
 .Pp
-.Nm write
+.Em WARNING:
+.Nm
+.Cm read
+is a dangerous command that can damage hardware and panic the operating
+system, even though it appears to be a harmless read-only operation.
+It is meant as a diagnostic tool for experiments or to debug device
+drivers.
+Do not use it as a substitute for a device driver!
+.Pp
+.Cm write
 .Op Fl b Ar bus
 .Fl d Ar device
 .Op Fl f Ar function
@@ -108,6 +117,15 @@ configuration register.
 If the bus is not specified, it defaults to the bus number of the
 PCI bus specified on the command line.
 If the function is not specified, it defaults to 0.
+.Pp
+.Em WARNING:
+.Nm
+.Cm read
+is a dangerous command that can damage hardware and panic the operating
+system.
+It is meant as a diagnostic tool for experiments or to debug device
+drivers.
+Do not use it as a substitute for a device driver!
 .Sh FILES
 .Pa /dev/pci*
 - PCI bus device nodes



CVS commit: src/usr.sbin/pcictl

2014-09-10 Thread Thomas Klausner
Module Name:src
Committed By:   wiz
Date:   Wed Sep 10 21:13:51 UTC 2014

Modified Files:
src/usr.sbin/pcictl: pcictl.8

Log Message:
Fix pasto.


To generate a diff of this commit:
cvs rdiff -u -r1.15 -r1.16 src/usr.sbin/pcictl/pcictl.8

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/usr.sbin/pcictl/pcictl.8
diff -u src/usr.sbin/pcictl/pcictl.8:1.15 src/usr.sbin/pcictl/pcictl.8:1.16
--- src/usr.sbin/pcictl/pcictl.8:1.15	Wed Sep 10 21:09:32 2014
+++ src/usr.sbin/pcictl/pcictl.8	Wed Sep 10 21:13:50 2014
@@ -1,4 +1,4 @@
-.\	$NetBSD: pcictl.8,v 1.15 2014/09/10 21:09:32 riastradh Exp $
+.\	$NetBSD: pcictl.8,v 1.16 2014/09/10 21:13:50 wiz Exp $
 .\
 .\ Copyright 2001 Wasabi Systems, Inc.
 .\ All rights reserved.
@@ -120,7 +120,7 @@ If the function is not specified, it def
 .Pp
 .Em WARNING:
 .Nm
-.Cm read
+.Cm write
 is a dangerous command that can damage hardware and panic the operating
 system.
 It is meant as a diagnostic tool for experiments or to debug device



CVS commit: src/external/bsd/nvi/docs/USD.doc/vi.ref

2014-09-10 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Wed Sep 10 21:44:22 UTC 2014

Modified Files:
src/external/bsd/nvi/docs/USD.doc/vi.ref: Makefile ref.so vi.ref

Log Message:
Fix the index building which got completely broken after the last update.


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/external/bsd/nvi/docs/USD.doc/vi.ref/Makefile
cvs rdiff -u -r1.1 -r1.2 src/external/bsd/nvi/docs/USD.doc/vi.ref/ref.so \
src/external/bsd/nvi/docs/USD.doc/vi.ref/vi.ref

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/external/bsd/nvi/docs/USD.doc/vi.ref/Makefile
diff -u src/external/bsd/nvi/docs/USD.doc/vi.ref/Makefile:1.4 src/external/bsd/nvi/docs/USD.doc/vi.ref/Makefile:1.5
--- src/external/bsd/nvi/docs/USD.doc/vi.ref/Makefile:1.4	Sat Jul  5 15:23:00 2014
+++ src/external/bsd/nvi/docs/USD.doc/vi.ref/Makefile	Wed Sep 10 17:44:22 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile,v 1.4 2014/07/05 19:23:00 dholland Exp $
+#	$NetBSD: Makefile,v 1.5 2014/09/10 21:44:22 christos Exp $
 #
 #	@(#)Makefile	8.20 (Berkeley) 8/18/96
 
@@ -6,6 +6,8 @@ SECTION=	reference/ref1
 ARTICLE=	vi
 SRCS=		vi.ref
 DEPSRCS=	ex.cmd.roff set.opt.roff vi.cmd.roff ref.so index.so
+# Add -U to the macros if you want to build the index since it needs
+# unsafe mode for .sy
 MACROS=		-me
 ROFF_TBL=	yes
 CLEANFILES+=	index index.so
@@ -14,12 +16,12 @@ CLEANFILES+=	index index.so
 
 # index.so is generated.
 index.so: vi.ref
-	${TOOL_SOELIM} vi.ref | ${TOOL_TBL} | \
+	${TOOL_SOELIM} -I${.CURDIR} ${.ALLSRC} | ${TOOL_TBL} | \
 	${TOOL_ROFF_PS} ${MACROS}  /dev/null
 	sed -e 's/MINUSSIGN/\\-/' \
 	-e 's/DOUBLEQUOTE//' \
 	-e s/SQUOTE/'/ \
 	-e 's/ /__SPACE/g'  index | \
-	sort -u '-t	' +0 -1 +1n | awk -f merge.awk | \
+	sort -u '-t	' +0 -1 +1n | awk -f ${.CURDIR}/merge.awk | \
 	sed -e 's/__SPACE/ /g'  $@
 	rm -f index

Index: src/external/bsd/nvi/docs/USD.doc/vi.ref/ref.so
diff -u src/external/bsd/nvi/docs/USD.doc/vi.ref/ref.so:1.1 src/external/bsd/nvi/docs/USD.doc/vi.ref/ref.so:1.2
--- src/external/bsd/nvi/docs/USD.doc/vi.ref/ref.so:1.1	Fri Nov 22 11:00:45 2013
+++ src/external/bsd/nvi/docs/USD.doc/vi.ref/ref.so	Wed Sep 10 17:44:22 2014
@@ -1,4 +1,4 @@
-.\	$NetBSD: ref.so,v 1.1 2013/11/22 16:00:45 christos Exp $
+.\	$NetBSD: ref.so,v 1.2 2014/09/10 21:44:22 christos Exp $
 .\
 .\ Copyright (c) 1994
 .\ The Regents of the University of California.  All rights reserved.
@@ -62,7 +62,7 @@
 ..
 .\ key words for index
 .de KY
-.sy echo index '\\$1	\\n%'
+.if \n[.U]==0 .sy echo index '\\$1	\\n%'
 ..
 .\ option names
 .de OP
Index: src/external/bsd/nvi/docs/USD.doc/vi.ref/vi.ref
diff -u src/external/bsd/nvi/docs/USD.doc/vi.ref/vi.ref:1.1 src/external/bsd/nvi/docs/USD.doc/vi.ref/vi.ref:1.2
--- src/external/bsd/nvi/docs/USD.doc/vi.ref/vi.ref:1.1	Fri Nov 22 11:00:45 2013
+++ src/external/bsd/nvi/docs/USD.doc/vi.ref/vi.ref	Wed Sep 10 17:44:22 2014
@@ -1,4 +1,4 @@
-.\	$NetBSD: vi.ref,v 1.1 2013/11/22 16:00:45 christos Exp $
+.\	$NetBSD: vi.ref,v 1.2 2014/09/10 21:44:22 christos Exp $
 .\
 .\ Copyright (c) 1994
 .\ The Regents of the University of California.  All rights reserved.
@@ -113,7 +113,7 @@ Engineers, Inc.
 The financial support of UUNET Communications Services is gratefully
 acknowledged.
 .)q
-.sy echo -n index
+.if \n[.U]==0 .sy echo -n index
 .oh 'Vi/Ex Reference''USD:13-%'
 .eh 'USD:13-%''Vi/Ex Reference'
 .bp 4



CVS commit: src/compat

2014-09-10 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Wed Sep 10 22:43:36 UTC 2014

Modified Files:
src/compat: archdirs.mk
src/compat/arm/eabihf: bsd.eabihf.mk

Log Message:
Enable building eabihf compat libraries after fixing bsd.eabihf.mk to use
use the proper variant of arm*--netbsdelf-eabihf


To generate a diff of this commit:
cvs rdiff -u -r1.6 -r1.7 src/compat/archdirs.mk
cvs rdiff -u -r1.1 -r1.2 src/compat/arm/eabihf/bsd.eabihf.mk

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/compat/archdirs.mk
diff -u src/compat/archdirs.mk:1.6 src/compat/archdirs.mk:1.7
--- src/compat/archdirs.mk:1.6	Mon Aug 11 04:33:30 2014
+++ src/compat/archdirs.mk	Wed Sep 10 22:43:36 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: archdirs.mk,v 1.6 2014/08/11 04:33:30 matt Exp $
+#	$NetBSD: archdirs.mk,v 1.7 2014/09/10 22:43:36 matt Exp $
 
 # list of subdirs used per-platform
 
@@ -32,7 +32,7 @@ ARCHDIR_SUBDIR= powerpc64/powerpc
 
 .if (${MACHINE_ARCH} == aarch64)
 ARCHDIR_SUBDIR+= arm/eabi
-#ARCHDIR_SUBDIR+= arm/eabihf
+ARCHDIR_SUBDIR+= arm/eabihf
 ARCHDIR_SUBDIR+= arm/oabi
 .elif (${MACHINE_ARCH} == aarch64eb)
 ARCHDIR_SUBDIR= arm/eabi

Index: src/compat/arm/eabihf/bsd.eabihf.mk
diff -u src/compat/arm/eabihf/bsd.eabihf.mk:1.1 src/compat/arm/eabihf/bsd.eabihf.mk:1.2
--- src/compat/arm/eabihf/bsd.eabihf.mk:1.1	Sun Aug 10 23:26:25 2014
+++ src/compat/arm/eabihf/bsd.eabihf.mk	Wed Sep 10 22:43:36 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: bsd.eabihf.mk,v 1.1 2014/08/10 23:26:25 matt Exp $
+#	$NetBSD: bsd.eabihf.mk,v 1.2 2014/09/10 22:43:36 matt Exp $
 
 .if !defined(MLIBDIR)
 
@@ -9,22 +9,22 @@ EARM_COMPAT_FLAGS+=	-mabi=aapcs-linux
 MKSOFTFLOAT=no
 
 .if ${MACHINE_ARCH} == aarch64eb
-EARM_COMPAT_FLAGS+=	-target armeb--netbsdelf-gnueabi
+EARM_COMPAT_FLAGS+=	-target armeb--netbsdelf-eabihf
 EARM_COMPAT_FLAGS+=	-mcpu=cortex-a53
 ARM_MACHINE_ARCH=	earmv7hfeb
 LDFLAGS+=		-Wl,--be8
 ARM_LD=			-m armelfb_nbsd_eabihf --be8
 .elif ${MACHINE_ARCH} == aarch64
-EARM_COMPAT_FLAGS+=	-target arm--netbsdelf-gnueabi
+EARM_COMPAT_FLAGS+=	-target arm--netbsdelf-eabihf
 EARM_COMPAT_FLAGS+=	-mcpu=cortex-a53
 ARM_MACHINE_ARCH=	earmv7hf
 ARM_LD=			-m armelf_nbsd_eabihf
 .elif !empty(MACHINE_ARCH:M*eb)
-EARM_COMPAT_FLAGS+=	-target armeb--netbsdelf-gnueabi
+EARM_COMPAT_FLAGS+=	-target armeb--netbsdelf-eabihf
 ARM_MACHINE_ARCH=	earmhfeb
 ARM_LD=			-m armelfb_nbsd_eabihf
 .else
-EARM_COMPAT_FLAGS+=	-target arm--netbsdelf-gnueabi
+EARM_COMPAT_FLAGS+=	-target arm--netbsdelf-eabihf
 ARM_MACHINE_ARCH=	earmhf
 ARM_LD=			-m armelf_nbsd_eabihf
 .endif



CVS commit: src/sys/dev/mii

2014-09-10 Thread Ryo Shimizu
Module Name:src
Committed By:   ryo
Date:   Wed Sep 10 22:46:34 UTC 2014

Modified Files:
src/sys/dev/mii: micphy.c

Log Message:
add __diagused


To generate a diff of this commit:
cvs rdiff -u -r1.1 -r1.2 src/sys/dev/mii/micphy.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/dev/mii/micphy.c
diff -u src/sys/dev/mii/micphy.c:1.1 src/sys/dev/mii/micphy.c:1.2
--- src/sys/dev/mii/micphy.c:1.1	Wed Feb 26 04:13:44 2014
+++ src/sys/dev/mii/micphy.c	Wed Sep 10 22:46:34 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: micphy.c,v 1.1 2014/02/26 04:13:44 ozaki-r Exp $	*/
+/*	$NetBSD: micphy.c,v 1.2 2014/09/10 22:46:34 ryo Exp $	*/
 
 /*-
  * Copyright (c) 1998, 1999, 2000 The NetBSD Foundation, Inc.
@@ -59,7 +59,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: micphy.c,v 1.1 2014/02/26 04:13:44 ozaki-r Exp $);
+__KERNEL_RCSID(0, $NetBSD: micphy.c,v 1.2 2014/09/10 22:46:34 ryo Exp $);
 
 #include opt_mii.h
 
@@ -219,7 +219,7 @@ micphy_service(struct mii_softc *sc, str
 
 static void micphy_writexreg(struct mii_softc *sc, uint32_t reg, uint32_t wval)
 {
-	int rval;
+	int rval __diagused;
 
 	PHY_WRITE(sc, XREG_CONTROL, XREG_CTL_SEL_WRITE | reg);
 	PHY_WRITE(sc, XREG_WRITE, wval);



CVS commit: src/distrib/sets/lists

2014-09-10 Thread Matt Thomas
Module Name:src
Committed By:   matt
Date:   Wed Sep 10 22:50:25 UTC 2014

Modified Files:
src/distrib/sets/lists/base: ad.aarch64
src/distrib/sets/lists/comp: ad.aarch64
src/distrib/sets/lists/debug: ad.aarch64

Log Message:
Uncomment/fix the eabihf compat entries


To generate a diff of this commit:
cvs rdiff -u -r1.4 -r1.5 src/distrib/sets/lists/base/ad.aarch64
cvs rdiff -u -r1.4 -r1.5 src/distrib/sets/lists/comp/ad.aarch64
cvs rdiff -u -r1.3 -r1.4 src/distrib/sets/lists/debug/ad.aarch64

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/sets/lists/base/ad.aarch64
diff -u src/distrib/sets/lists/base/ad.aarch64:1.4 src/distrib/sets/lists/base/ad.aarch64:1.5
--- src/distrib/sets/lists/base/ad.aarch64:1.4	Fri Aug 22 10:51:38 2014
+++ src/distrib/sets/lists/base/ad.aarch64	Wed Sep 10 22:50:25 2014
@@ -1,4 +1,4 @@
-# $NetBSD: ad.aarch64,v 1.4 2014/08/22 10:51:38 apb Exp $
+# $NetBSD: ad.aarch64,v 1.5 2014/09/10 22:50:25 matt Exp $
 ./lib/eabi	base-compat-shlib	compat
 ./lib/eabi/npf	base-npf-shlib		compat
 ./lib/eabi/npf/ext_log.so			base-npf-shlib		compat,pic
@@ -12,15 +12,15 @@
 ./lib/eabi/npf/ext_rndblock.so.0.0		base-npf-shlib		compat,pic
 ./lib/eabihf	base-compat-shlib	compat
 ./lib/eabihf/npfbase-npf-shlib		compat
-#./lib/eabihf/npf/ext_log.so			base-npf-shlib		compat,pic
-#./lib/eabihf/npf/ext_log.so.0			base-npf-shlib		compat,pic
-#./lib/eabihf/npf/ext_log.so.0.0		base-npf-shlib		compat,pic
-#./lib/eabihf/npf/ext_normalize.so		base-npf-shlib		compat,pic
-#./lib/eabihf/npf/ext_normalize.so.0		base-npf-shlib		compat,pic
-#./lib/eabihf/npf/ext_normalize.so.0.0		base-npf-shlib		compat,pic
-#./lib/eabihf/npf/ext_rndblock.so		base-npf-shlib		compat,pic
-#./lib/eabihf/npf/ext_rndblock.so.0		base-npf-shlib		compat,pic
-#./lib/eabihf/npf/ext_rndblock.so.0.0		base-npf-shlib		compat,pic
+./lib/eabihf/npf/ext_log.so			base-npf-shlib		compat,pic
+./lib/eabihf/npf/ext_log.so.0			base-npf-shlib		compat,pic
+./lib/eabihf/npf/ext_log.so.0.0		base-npf-shlib		compat,pic
+./lib/eabihf/npf/ext_normalize.so		base-npf-shlib		compat,pic
+./lib/eabihf/npf/ext_normalize.so.0		base-npf-shlib		compat,pic
+./lib/eabihf/npf/ext_normalize.so.0.0		base-npf-shlib		compat,pic
+./lib/eabihf/npf/ext_rndblock.so		base-npf-shlib		compat,pic
+./lib/eabihf/npf/ext_rndblock.so.0		base-npf-shlib		compat,pic
+./lib/eabihf/npf/ext_rndblock.so.0.0		base-npf-shlib		compat,pic
 ./lib/oabi	base-compat-shlib	compat
 ./lib/oabi/npf	base-npf-shlib		compat
 ./lib/oabi/npf/ext_log.so			base-npf-shlib		compat,pic
@@ -33,7 +33,7 @@
 ./lib/oabi/npf/ext_rndblock.so.0		base-npf-shlib		compat,pic
 ./lib/oabi/npf/ext_rndblock.so.0.0		base-npf-shlib		compat,pic
 ./libexec/ld.elf_so-eabi			base-compat-shlib	compat,pic
-#./libexec/ld.elf_so-eabihf			base-compat-shlib	compat,pic
+./libexec/ld.elf_so-eabihf			base-compat-shlib	compat,pic
 ./libexec/ld.elf_so-oabi			base-sysutil-bin	compat,pic
 ./usr/lib/eabi	base-compat-lib		compat
 ./usr/lib/eabi/i18nbase-compat-lib		compat
@@ -351,318 +351,318 @@
 ./usr/lib/eabi/security/pam_unix.so.4		base-compat-shlib	compat,pic,pam
 ./usr/lib/eabihfbase-compat-lib		compat
 ./usr/lib/eabihf/i18nbase-compat-lib		compat
-#./usr/lib/eabihf/i18n/libBIG5.so.5		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libBIG5.so.5.0		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libDECHanyu.so.5		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libDECHanyu.so.5.0		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libEUC.so.5			base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libEUC.so.5.0		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libEUCTW.so.5		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libEUCTW.so.5.0		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libGBK2K.so.5		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libGBK2K.so.5.0		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libHZ.so.5			base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libHZ.so.5.0		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libISO2022.so.5		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libISO2022.so.5.0		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libJOHAB.so.5			base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libJOHAB.so.5.0		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libMSKanji.so.5		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libMSKanji.so.5.0		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libUES.so.5			base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libUES.so.5.0			base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libUTF1632.so.5		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libUTF1632.so.5.0		base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libUTF7.so.5			base-i18n-shlib		compat,pic
-#./usr/lib/eabihf/i18n/libUTF7.so.5.0		base-i18n-shlib		compat,pic

CVS commit: src/sys/arch/arm/allwinner

2014-09-10 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Thu Sep 11 00:50:39 UTC 2014

Modified Files:
src/sys/arch/arm/allwinner: awin_reg.h

Log Message:
add some HDMI regs


To generate a diff of this commit:
cvs rdiff -u -r1.23 -r1.24 src/sys/arch/arm/allwinner/awin_reg.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/allwinner/awin_reg.h
diff -u src/sys/arch/arm/allwinner/awin_reg.h:1.23 src/sys/arch/arm/allwinner/awin_reg.h:1.24
--- src/sys/arch/arm/allwinner/awin_reg.h:1.23	Mon Sep  8 11:06:03 2014
+++ src/sys/arch/arm/allwinner/awin_reg.h	Thu Sep 11 00:50:39 2014
@@ -872,6 +872,10 @@ struct awin_mmc_idma_descriptor {
 #define AWIN_PLL6_PLL_BIAS		__BITS(24,20)
 #define AWIN_PLL6_CFG_SATA_CLK_EN	__BIT(14)
 
+#define AWIN_PLL7_MODE_SEL		__BIT(15)
+#define AWIN_PLL7_FRAC_SET		__BIT(14)
+#define AWIN_PLL7_FACTOR_M		__BITS(6,0)
+
 #define AWIN_CPU_CLK_SRC_SEL		__BITS(17,16)
 #define AWIN_CPU_CLK_SRC_SEL_LOSC	0
 #define AWIN_CPU_CLK_SRC_SEL_OSC24M	1
@@ -1005,6 +1009,13 @@ struct awin_mmc_idma_descriptor {
 #define AWIN_GMAC_CLK_TCS_EXT_125	1
 #define AWIN_GMAC_CLK_TCS_INT_RGMII	2
 
+#define AWIN_HDMI_CLK_SRC_SEL		__BITS(25,24)
+#define AWIN_HDMI_CLK_SRC_SEL_PLL3	0
+#define AWIN_HDMI_CLK_SRC_SEL_PLL7	1
+#define AWIN_HDMI_CLK_SRC_SEL_PLL3_2X	2
+#define AWIN_HDMI_CLK_SRC_SEL_PLL7_2X	3
+#define AWIN_HDMI_CLK_DIV_RATIO_M	__BITS(3,0)
+
 #define AWIN_CLK_OUT_ENABLE		__BIT(31)
 #define AWIN_CLK_OUT_SRC_SEL		__BITS(25,24)
 #define AWIN_CLK_OUT_SRC_SEL_32K	0
@@ -1448,4 +1459,187 @@ struct awin_mmc_idma_descriptor {
 #define AWIN_HSTMR_TMR3_CURNT_LO_REG	0x007c
 #define AWIN_HSTMR_TMR3_CURNT_HI_REG	0x0080
 
+/* HDMI */
+#define AWIN_HDMI_VERSION_ID_REG	0x
+#define AWIN_HDMI_CTRL_REG		0x0004
+#define AWIN_HDMI_INT_STATUS_REG	0x0008
+#define AWIN_HDMI_HPD_REG		0x000c
+#define AWIN_HDMI_VID_CTRL_REG		0x0010
+#define AWIN_HDMI_VID_TIMING_0_REG	0x0014
+#define AWIN_HDMI_VID_TIMING_1_REG	0x0018
+#define AWIN_HDMI_VID_TIMING_2_REG	0x001c
+#define AWIN_HDMI_VID_TIMING_3_REG	0x0020
+#define AWIN_HDMI_VID_TIMING_4_REG	0x0024
+#define AWIN_HDMI_AUD_CTRL_REG		0x0040
+#define AWIN_HDMI_ADMA_CTRL_REG		0x0044
+#define AWIN_HDMI_AUD_FMT_REG		0x0048
+#define AWIN_HDMI_AUD_PCM_CTRL_REG	0x004c
+#define AWIN_HDMI_AUD_CTS_REG		0x0050
+#define AWIN_HDMI_AUD_N_REG		0x0054
+#define AWIN_HDMI_AUD_CH_STATUS0_REG	0x0058
+#define AWIN_HDMI_AUD_CH_STATUS1_REG	0x005c
+#define AWIN_HDMI_AVI_INFO_PKT_REG	0x0080
+#define AWIN_HDMI_AUD_INFO_PKT_REG	0x00a0
+#define AWIN_HDMI_ACP_PKT_REG		0x00c0
+#define AWIN_HDMI_GP_PKT_REG		0x00e0
+#define AWIN_HDMI_PAD_CTRL0_REG		0x0200
+#define AWIN_HDMI_PAD_CTRL1_REG		0x0204
+#define AWIN_HDMI_PLL_CTRL_REG		0x0208
+#define AWIN_HDMI_PLL_DBG0_REG		0x020c
+#define AWIN_HDMI_PLL_DBG1_REG		0x0210
+#define AWIN_HDMI_HPD_CEC_REG		0x0214
+#define AWIN_HDMI_SPD_PKT_REG		0x0240
+#define AWIN_HDMI_PKT_CTRL0_REG		0x02f0
+#define AWIN_HDMI_PKT_CTRL1_REG		0x02f4
+#define AWIN_HDMI_DBG4_REG		0x0310
+#define AWIN_HDMI_AUX_TX_FIFO_REG	0x0400
+#define AWIN_HDMI_DDC_CTRL_REG		0x0500
+#define AWIN_HDMI_DDC_SLAVE_ADDR_REG	0x0504
+#define AWIN_HDMI_DDC_INT_MASK_REG	0x0508
+#define AWIN_HDMI_DDC_INT_STATUS_REG	0x050c
+#define AWIN_HDMI_DDC_FIFO_CTRL_REG	0x0510
+#define AWIN_HDMI_DDC_FIFO_STATUS_REG	0x0514
+#define AWIN_HDMI_DDC_FIFO_ACCESS_REG	0x0518
+#define AWIN_HDMI_DDC_BYTE_COUNTER_REG	0x051c
+#define AWIN_HDMI_DDC_COMMAND_REG	0x0520
+#define AWIN_HDMI_DDC_EX_REG		0x0524
+#define AWIN_HDMI_DDC_CLOCK_REG		0x0528
+#define AWIN_HDMI_DDC_DBG_REG		0x0540
+
+#define AWIN_HDMI_VERSION_ID_H		__BITS(31,16)
+#define AWIN_HDMI_VERSION_ID_L		__BITS(15,0)
+
+#define AWIN_HDMI_CTRL_MODULE_EN	__BIT(31)
+#define AWIN_HDMI_CTRL_HDCP_EN		__BIT(30)
+#define AWIN_HDMI_CTRL_CLR_AVMUTE	__BIT(1)
+#define AWIN_HDMI_CTRL_SET_AVMUTE	__BIT(0)
+
+#define AWIN_HDMI_HPD_HOTPLUG_DET	__BIT(0)
+
+#define AWIN_HDMI_VID_CTRL_VIDEO_EN	__BIT(31)
+#define AWIN_HDMI_VID_CTRL_HDMI_MODE	__BIT(30)
+#define AWIN_HDMI_VID_CTRL_HDMI_MODE_DVI	0
+#define AWIN_HDMI_VID_CTRL_HDMI_MODE_HDMI	1
+#define AWIN_HDMI_VID_CTRL_SRC_SEL	__BIT(5)
+#define AWIN_HDMI_VID_CTRL_SRC_SEL_RGB		0
+#define AWIN_HDMI_VID_CTRL_SRC_SEL_CBGEN	1
+#define AWIN_HDMI_VID_CTRL_OUTPUT_FMT	__BIT(4)
+#define AWIN_HDMI_VID_CTRL_OUTPUT_FMT_PROGRESS	0
+#define AWIN_HDMI_VID_CTRL_OUTPUT_FMT_INTERLACE	1
+#define AWIN_HDMI_VID_CTRL_COLOR_MODE	__BITS(3,2)
+#define AWIN_HDMI_VID_CTRL_COLOR_MODE_24	0
+#define AWIN_HDMI_VID_CTRL_COLOR_MODE_30	1
+#define AWIN_HDMI_VID_CTRL_COLOR_MODE_36	2
+#define AWIN_HDMI_VID_CTRL_COLOR_MODE_48	3
+#define AWIN_HDMI_VID_CTRL_REPEATER_SEL	__BITS(1,0)
+#define AWIN_HDMI_VID_CTRL_REPEATER_SEL_NORMAL	0
+#define AWIN_HDMI_VID_CTRL_REPEATER_SEL_2X	1
+#define AWIN_HDMI_VID_CTRL_REPEATER_SEL_4X	2
+
+#define AWIN_HDMI_VID_TIMING_0_ACT_V	__BITS(27,16)
+#define AWIN_HDMI_VID_TIMING_0_ACT_H	__BITS(11,0)
+
+#define AWIN_HDMI_VID_TIMING_1_VBP	__BITS(27,16)
+#define 

CVS commit: src/sys/arch/arm/allwinner

2014-09-10 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Thu Sep 11 02:16:15 UTC 2014

Modified Files:
src/sys/arch/arm/allwinner: awin_board.c awin_var.h

Log Message:
PLL7 setup for HDMI on A20


To generate a diff of this commit:
cvs rdiff -u -r1.17 -r1.18 src/sys/arch/arm/allwinner/awin_board.c
cvs rdiff -u -r1.15 -r1.16 src/sys/arch/arm/allwinner/awin_var.h

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/allwinner/awin_board.c
diff -u src/sys/arch/arm/allwinner/awin_board.c:1.17 src/sys/arch/arm/allwinner/awin_board.c:1.18
--- src/sys/arch/arm/allwinner/awin_board.c:1.17	Sun Sep  7 22:21:36 2014
+++ src/sys/arch/arm/allwinner/awin_board.c	Thu Sep 11 02:16:15 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: awin_board.c,v 1.17 2014/09/07 22:21:36 jmcneill Exp $	*/
+/*	$NetBSD: awin_board.c,v 1.18 2014/09/11 02:16:15 jmcneill Exp $	*/
 /*-
  * Copyright (c) 2012 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -35,7 +35,7 @@
 
 #include sys/cdefs.h
 
-__KERNEL_RCSID(1, $NetBSD: awin_board.c,v 1.17 2014/09/07 22:21:36 jmcneill Exp $);
+__KERNEL_RCSID(1, $NetBSD: awin_board.c,v 1.18 2014/09/11 02:16:15 jmcneill Exp $);
 
 #include sys/param.h
 #include sys/bus.h
@@ -335,3 +335,25 @@ awin_pll2_enable(void)
 		AWIN_CCM_OFFSET + AWIN_PLL2_CFG_REG, ncfg);
 	}
 }
+
+void
+awin_pll7_enable(void)
+{
+	bus_space_tag_t bst = awin_bs_tag;
+	bus_space_handle_t bsh = awin_core_bsh;
+
+	/*
+	 * HDMI needs PLL7 to be 2970 Hz
+	 */
+	const uint32_t ocfg = bus_space_read_4(bst, bsh,
+	AWIN_CCM_OFFSET + AWIN_PLL7_CFG_REG);
+
+	uint32_t ncfg = ocfg;
+	ncfg = ~(AWIN_PLL7_MODE_SEL|AWIN_PLL7_FRAC_SET|AWIN_PLL7_FACTOR_M);
+	ncfg |= AWIN_PLL7_FRAC_SET;
+	ncfg |= AWIN_PLL_CFG_ENABLE;
+	if (ncfg != ocfg) {
+		bus_space_write_4(bst, bsh,
+		AWIN_CCM_OFFSET + AWIN_PLL7_CFG_REG, ncfg);
+	}
+}

Index: src/sys/arch/arm/allwinner/awin_var.h
diff -u src/sys/arch/arm/allwinner/awin_var.h:1.15 src/sys/arch/arm/allwinner/awin_var.h:1.16
--- src/sys/arch/arm/allwinner/awin_var.h:1.15	Tue Sep  9 13:56:30 2014
+++ src/sys/arch/arm/allwinner/awin_var.h	Thu Sep 11 02:16:15 2014
@@ -1,4 +1,4 @@
-/* $NetBSD: awin_var.h,v 1.15 2014/09/09 13:56:30 jmcneill Exp $ */
+/* $NetBSD: awin_var.h,v 1.16 2014/09/11 02:16:15 jmcneill Exp $ */
 /*-
  * Copyright (c) 2013 The NetBSD Foundation, Inc.
  * All rights reserved.
@@ -91,6 +91,7 @@ void	awin_bootstrap(vaddr_t, vaddr_t); 
 void	awin_dma_bootstrap(psize_t);
 void	awin_pll2_enable(void);
 void	awin_pll6_enable(void);
+void	awin_pll7_enable(void);
 void	awin_cpu_hatch(struct cpu_info *);
 
 #define AWIN_CHIP_ID_A10	0x1623



CVS commit: src/sys/arch/arm/allwinner

2014-09-10 Thread Jared D. McNeill
Module Name:src
Committed By:   jmcneill
Date:   Thu Sep 11 02:21:19 UTC 2014

Modified Files:
src/sys/arch/arm/allwinner: awin_io.c files.awin
Added Files:
src/sys/arch/arm/allwinner: awin_hdmi.c

Log Message:
work in progress HDMI driver, so far it can detect display presence and read 
the display EDID


To generate a diff of this commit:
cvs rdiff -u -r0 -r1.1 src/sys/arch/arm/allwinner/awin_hdmi.c
cvs rdiff -u -r1.14 -r1.15 src/sys/arch/arm/allwinner/awin_io.c
cvs rdiff -u -r1.12 -r1.13 src/sys/arch/arm/allwinner/files.awin

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/sys/arch/arm/allwinner/awin_io.c
diff -u src/sys/arch/arm/allwinner/awin_io.c:1.14 src/sys/arch/arm/allwinner/awin_io.c:1.15
--- src/sys/arch/arm/allwinner/awin_io.c:1.14	Tue Sep  9 13:57:03 2014
+++ src/sys/arch/arm/allwinner/awin_io.c	Thu Sep 11 02:21:19 2014
@@ -31,7 +31,7 @@
 
 #include sys/cdefs.h
 
-__KERNEL_RCSID(1, $NetBSD: awin_io.c,v 1.14 2014/09/09 13:57:03 jmcneill Exp $);
+__KERNEL_RCSID(1, $NetBSD: awin_io.c,v 1.15 2014/09/11 02:21:19 jmcneill Exp $);
 
 #include sys/param.h
 #include sys/bus.h
@@ -106,6 +106,7 @@ static const struct awin_locators awin_l
 	{ com, OFFANDSIZE(UART7), 7, AWIN_IRQ_UART7, AANY },
 	{ awinwdt, OFFANDSIZE(TMR), NOPORT, NOINTR, AANY },
 	{ awinrtc, OFFANDSIZE(TMR), NOPORT, NOINTR, AANY },
+	{ awinhdmi, OFFANDSIZE(HDMI), NOPORT, AWIN_IRQ_HDMI0, A20 },
 	{ awinusb, OFFANDSIZE(USB1), 0, NOINTR, AANY },
 	{ awinusb, OFFANDSIZE(USB2), 1, NOINTR, AANY },
 	{ motg, OFFANDSIZE(USB0), NOPORT, AWIN_IRQ_USB0, AANY },

Index: src/sys/arch/arm/allwinner/files.awin
diff -u src/sys/arch/arm/allwinner/files.awin:1.12 src/sys/arch/arm/allwinner/files.awin:1.13
--- src/sys/arch/arm/allwinner/files.awin:1.12	Mon Sep  8 14:26:16 2014
+++ src/sys/arch/arm/allwinner/files.awin	Thu Sep 11 02:21:19 2014
@@ -1,4 +1,4 @@
-#	$NetBSD: files.awin,v 1.12 2014/09/08 14:26:16 martin Exp $
+#	$NetBSD: files.awin,v 1.13 2014/09/11 02:21:19 jmcneill Exp $
 #
 # Configuration info for Allwinner ARM Peripherals
 #
@@ -115,3 +115,8 @@ file	arch/arm/allwinner/awin_ahcisata.c	
 device	awinac: audiobus, auconv, mulaw, aurateconv
 attach	awinac at awinio with awin_ac
 file	arch/arm/allwinner/awin_ac.c		awin_ac
+
+# A10/A20 HDMI
+device	awinhdmi: edid, ddc_read_edid
+attach	awinhdmi at awinio with awin_hdmi
+file	arch/arm/allwinner/awin_hdmi.c		awin_hdmi

Added files:

Index: src/sys/arch/arm/allwinner/awin_hdmi.c
diff -u /dev/null src/sys/arch/arm/allwinner/awin_hdmi.c:1.1
--- /dev/null	Thu Sep 11 02:21:19 2014
+++ src/sys/arch/arm/allwinner/awin_hdmi.c	Thu Sep 11 02:21:19 2014
@@ -0,0 +1,430 @@
+/* $NetBSD: awin_hdmi.c,v 1.1 2014/09/11 02:21:19 jmcneill Exp $ */
+
+/*-
+ * Copyright (c) 2014 Jared D. McNeill jmcne...@invisible.ca
+ * All rights reserved.
+ *
+ * Redistribution and use in source and binary forms, with or without
+ * modification, are permitted provided that the following conditions
+ * are met:
+ * 1. Redistributions of source code must retain the above copyright
+ *notice, this list of conditions and the following disclaimer.
+ * 2. Redistributions in binary form must reproduce the above copyright
+ *notice, this list of conditions and the following disclaimer in the
+ *documentation and/or other materials provided with the distribution.
+ *
+ * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
+ * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
+ * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
+ * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
+ * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
+ * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+ * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
+ * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
+ * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
+ * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
+ * SUCH DAMAGE.
+ */
+
+#include sys/cdefs.h
+__KERNEL_RCSID(0, $NetBSD: awin_hdmi.c,v 1.1 2014/09/11 02:21:19 jmcneill Exp $);
+
+#include sys/param.h
+#include sys/bus.h
+#include sys/device.h
+#include sys/intr.h
+#include sys/systm.h
+#include sys/kernel.h
+#include sys/proc.h
+#include sys/mutex.h
+#include sys/kthread.h
+
+#include arm/allwinner/awin_reg.h
+#include arm/allwinner/awin_var.h
+
+#include dev/i2c/i2cvar.h
+#include dev/i2c/ddcvar.h
+#include dev/i2c/ddcreg.h
+#include dev/videomode/videomode.h
+#include dev/videomode/edidvar.h
+
+/* NB: Should be 16, but it doesn't seem to work */
+#define HDMI_I2C_MAX_BLKLEN	1
+
+struct awin_hdmi_softc {
+	device_t sc_dev;
+	bus_space_tag_t sc_bst;
+	bus_space_handle_t sc_bsh;
+	void *sc_ih;
+	lwp_t *sc_thread;
+
+	struct i2c_controller sc_ic;
+	kmutex_t sc_ic_lock;
+
+	bool 

CVS commit: src/lib/libperfuse

2014-09-10 Thread Emmanuel Dreyfus
Module Name:src
Committed By:   manu
Date:   Thu Sep 11 04:05:52 UTC 2014

Modified Files:
src/lib/libperfuse: ops.c

Log Message:
Avoid a file resize serialization deadlock when writing with
PUFFS_IO_APPEND flag. The symptom was a hang when appending to
a file with a null size.


To generate a diff of this commit:
cvs rdiff -u -r1.73 -r1.74 src/lib/libperfuse/ops.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/lib/libperfuse/ops.c
diff -u src/lib/libperfuse/ops.c:1.73 src/lib/libperfuse/ops.c:1.74
--- src/lib/libperfuse/ops.c:1.73	Fri Sep  5 15:20:16 2014
+++ src/lib/libperfuse/ops.c	Thu Sep 11 04:05:52 2014
@@ -1,4 +1,4 @@
-/*  $NetBSD: ops.c,v 1.73 2014/09/05 15:20:16 manu Exp $ */
+/*  $NetBSD: ops.c,v 1.74 2014/09/11 04:05:52 manu Exp $ */
 
 /*-
  *  Copyright (c) 2010-2011 Emmanuel Dreyfus. All rights reserved.
@@ -3198,16 +3198,6 @@ perfuse_node_write2(struct puffs_usermou
 		requeue_request(pu, opc, PCQ_WRITE);
 	pnd-pnd_flags |= PND_INWRITE;
 
-	/* 
-	 * Serialize size access, see comment in perfuse_node_setattr().
-	 */
-	if ((u_quad_t)offset + *resid  vap-va_size) {
-		while (pnd-pnd_flags  PND_INRESIZE)
-			requeue_request(pu, opc, PCQ_RESIZE);
-		pnd-pnd_flags |= PND_INRESIZE;
-		inresize = 1;
-	}
-
 	/*
 	 * append flag: re-read the file size so that 
 	 * we get the latest value.
@@ -3219,6 +3209,16 @@ perfuse_node_write2(struct puffs_usermou
 		offset = vap-va_size;
 	}
 
+	/* 
+	 * Serialize size access, see comment in perfuse_node_setattr().
+	 */
+	if ((u_quad_t)offset + *resid  vap-va_size) {
+		while (pnd-pnd_flags  PND_INRESIZE)
+			requeue_request(pu, opc, PCQ_RESIZE);
+		pnd-pnd_flags |= PND_INRESIZE;
+		inresize = 1;
+	}
+
 #ifdef PERFUSE_DEBUG
 	if (perfuse_diagflags  PDF_RESIZE)
 		DPRINTF( %s %p % PRIu64 \n, __func__,
Index: src/sys/external/bsd/drm2/ttm/ttm_bo_vm.c
diff -u src/sys/external/bsd/drm2/ttm/ttm_bo_vm.c:1.4 src/sys/external/bsd/drm2/ttm/ttm_bo_vm.c:1.5
--- src/sys/external/bsd/drm2/ttm/ttm_bo_vm.c:1.4	Wed Aug 20 13:48:08 2014
+++ src/sys/external/bsd/drm2/ttm/ttm_bo_vm.c	Wed Sep 10 18:24:16 2014
@@ -1,4 +1,4 @@
-/*	$NetBSD: ttm_bo_vm.c,v 1.4 2014/08/20 13:48:08 riastradh Exp $	*/
+/*	$NetBSD: ttm_bo_vm.c,v 1.5 2014/09/10 18:24:16 riastradh Exp $	*/
 
 /*-
  * Copyright (c) 2014 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include sys/cdefs.h
-__KERNEL_RCSID(0, $NetBSD: ttm_bo_vm.c,v 1.4 2014/08/20 13:48:08 riastradh Exp $);
+__KERNEL_RCSID(0, $NetBSD: ttm_bo_vm.c,v 1.5 2014/09/10 18:24:16 riastradh Exp $);
 
 #include sys/types.h
 
@@ -107,9 +107,11 @@ ttm_bo_uvm_fault(struct uvm_faultinfo *u
 		if (ret != -EBUSY)
 			goto out0;
 		/*
 		 * It's currently locked.  Unlock the fault, wait for
 		 * it, and start over.
 		 */
+		mutex_enter(uobj-vmobjlock);
 		uvmfault_unlockall(ufi, ufi-entry-aref.ar_amap, uobj);
 		(void)ttm_bo_wait_unreserved(bo);
 		return -ERESTART;
@@ -107,9 +107,11 @@ ttm_bo_uvm_fault(struct uvm_faultinfo *u
 			goto out0;
 		/*
-		 * It's currently locked.  Unlock the fault, wait for
-		 * it, and start over.
+		 * It's currently locked.  Unlock the fault (requires
+		 * relocking uobj's vmobjlock first), wait for it, and
+		 * start over.
 		 */



CVS commit: src/crypto/dist/ipsec-tools/src/setkey

2014-09-10 Thread Christos Zoulas
Module Name:src
Committed By:   christos
Date:   Wed Sep 10 21:01:33 UTC 2014

Modified Files:
src/crypto/dist/ipsec-tools/src/setkey: token.l

Log Message:
remove dup


To generate a diff of this commit:
cvs rdiff -u -r1.18 -r1.19 src/crypto/dist/ipsec-tools/src/setkey/token.l

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:
